@@ -14,7 +14,7 @@
 #Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 from gi.repository import Atspi
-from pyatspi.enum import *
+from pyatspi.atspienum import *
 from pyatspi.utils import *
 from pyatspi.interface import *
 
@@ -43,7 +43,7 @@ __all__ = [
 
 #------------------------------------------------------------------------------
 
-class TEXT_BOUNDARY_TYPE(Enum):
+class TEXT_BOUNDARY_TYPE(AtspiEnum):
         _enum_lookup = {
                 0:'TEXT_BOUNDARY_CHAR',
                 1:'TEXT_BOUNDARY_WORD_START',
@@ -64,7 +64,7 @@ TEXT_BOUNDARY_WORD_START = TEXT_BOUNDARY_TYPE(1)
 
 #------------------------------------------------------------------------------
 
-class TEXT_CLIP_TYPE(Enum):
+class TEXT_CLIP_TYPE(AtspiEnum):
         _enum_lookup = {
                 0:'TEXT_CLIP_NONE',
                 1:'TEXT_CLIP_MIN',
@@ -79,7 +79,7 @@ TEXT_CLIP_NONE = TEXT_CLIP_TYPE(0)
 
 #------------------------------------------------------------------------------
 
-class TEXT_GRANULARITY_TYPE(Enum):
+class TEXT_GRANULARITY_TYPE(AtspiEnum):
         _enum_lookup = {
                 0:'TEXT_GRANULARITY_CHAR',
                 1:'TEXT_GRANULARITY_WORD',
@@ -406,8 +406,6 @@ class Text(interface):
                 startOffset (inclusive) up to but not including the character
                 at endOffset.
                 """
-                if not endOffset:
-                        endOffset = -1
                 return Atspi.Text.get_text(self.obj, startOffset, endOffset)
 
         def getTextAfterOffset(self, offset, type):
@@ -588,6 +586,22 @@ class Text(interface):
                 """
         characterCount = property(fget=get_characterCount, doc=_characterCountDoc)
 
+        def scrollSubstringTo(self, startOffset, endOffset, scroll_type):
+                """
+                Makes the text range visible on the screen at a given position by
+                scrolling all necessary parents.
+                @return True if scrolling was successful.
+                """
+                return Atspi.Text.scroll_substring_to(self.obj, startOffset, endOffset, scroll_type)
+
+        def scrollSubstringToPoint(self, startOffset, endOffset, coord_type, x, y):
+                """
+                Makes the text range visible on the screen at a given position by
+                scrolling all necessary parents.
+                @return True if scrolling was successful.
+                """
+                return Atspi.Text.scroll_substring_to_point(self.obj, startOffset, endOffset, coord_type, x, y)
+
 def rangeToList(r):
         return (r.start_offset, r.end_offset)
 
